@@ -271,7 +271,43 @@ void Control::stop (bool keep_fullscreen) {
         setCurrent (0L);
     }
     VIEWAREA(m_app)->reset ();
+
+    NodePtr recent = recents->firstChild ();
+    Mrl *mrl = m_process->mrl ();
+    if (recent && mrl &&
+            m_process->isLocalFile () &&
+            recent->mrl ()->src == mrl->src) {
+        Mrl *recent_mrl = recent->mrl ();
+        String ts = recent_mrl->getAttribute ("clipBegin");
+        int pos = m_process->userStopPosition ();
+        pos = pos > 50 ? pos - 50 : 0;
+        if (mrl->id == id_node_document)
+            mrl->clip_begin = pos;
+        String nts;
+        int ds = pos % 10;
+        if (ds > 0)
+            nts = String (Char ('.')) + String::number (ds);
+        pos /= 10;
+        int s = pos % 60;
+        nts = String::number (s) + nts;
+        pos /= 60;
+        if (pos > 0) {
+            int m = pos % 60;
+            nts = String::number (m) + String (Char (':')) + nts;
+            pos /= 60;
+            if (pos > 0) {
+                if (m  < 10)
+                    nts = String (Char ('0')) + nts;
+                nts = String::number (pos) + String (Char (':')) + nts;
+            }
+        }
+        if (ts != nts) {
+            recent_mrl->setAttribute ("clipBegin", nts);
+            recents->document ()->m_tree_version++;
+        }
+    }
     m_process->quit ();
+
     VIEWAREA(m_app)->scheduleRepaint (IRect (0, 0,
                     VIEWAREA(m_app)->width (), VIEWAREA(m_app)->height ()));
     if (!keep_fullscreen)
@@ -947,6 +983,7 @@ void cb_playlist_next (GtkButton * button, void *p) {
 void cb_playlist_stop (GtkButton * button, void *p) {
     Control *ctr = (Control *)p;
     if (GTK_WIDGET_VISIBLE (ctr->m_app->tb_stop)) {
+        ctr->process ()->setUserStop ();
         ctr->stop ();
     } else if (ctr->current_selected) {
         ctr->request_download = true;
